:orphan:

==================
Examples
==================

Here you can find some examples of how to use the library.


.. raw:: html

    <div class="sphx-glr-thumbnails">


.. raw:: html

    </div>

1 | Single-Set Analysis
=======================



.. raw:: html

    <div class="sphx-glr-thumbnails">


.. raw:: html

    <div class="sphx-glr-thumbcontainer" tooltip="This example demonstrates Extended EOF (EEOF) analysis on xarray tutorial data. EEOF analysis, ...">

.. only:: html

  .. image:: /content/user_guide/auto_examples/1single/images/thumb/sphx_glr_plot_eeof_thumb.png
    :alt:

  :ref:`sphx_glr_content_user_guide_auto_examples_1single_plot_eeof.py`

.. raw:: html

      <div class="sphx-glr-thumbnail-title">Extented EOF analysis</div>
    </div>


.. raw:: html

    <div class="sphx-glr-thumbcontainer" tooltip="In this tutorial, we&#x27;ll walk through how to perform a Complex EOF analysis on the zonal and mer...">

.. only:: html

  .. image:: /content/user_guide/auto_examples/1single/images/thumb/sphx_glr_plot_complex_eof_thumb.png
    :alt:

  :ref:`sphx_glr_content_user_guide_auto_examples_1single_plot_complex_eof.py`

.. raw:: html

      <div class="sphx-glr-thumbnail-title">Complex EOF analysis</div>
    </div>


.. raw:: html

    <div class="sphx-glr-thumbcontainer" tooltip="EOF analysis in T-mode maximises the spatial variance.">

.. only:: html

  .. image:: /content/user_guide/auto_examples/1single/images/thumb/sphx_glr_plot_eof-tmode_thumb.png
    :alt:

  :ref:`sphx_glr_content_user_guide_auto_examples_1single_plot_eof-tmode.py`

.. raw:: html

      <div class="sphx-glr-thumbnail-title">EOF analysis (T-mode)</div>
    </div>


.. raw:: html

    <div class="sphx-glr-thumbcontainer" tooltip="We demonstrate how to execute a Hilbert EOF analysis [1]_ [2]_ [3]_. This method extends tradit...">

.. only:: html

  .. image:: /content/user_guide/auto_examples/1single/images/thumb/sphx_glr_plot_hilbert_eof_thumb.png
    :alt:

  :ref:`sphx_glr_content_user_guide_auto_examples_1single_plot_hilbert_eof.py`

.. raw:: html

      <div class="sphx-glr-thumbnail-title">Hilbert EOF analysis</div>
    </div>


.. raw:: html

    <div class="sphx-glr-thumbcontainer" tooltip="This example demonstrates the application of sparse PCA [1]_ to sea surface temperature data. S...">

.. only:: html

  .. image:: /content/user_guide/auto_examples/1single/images/thumb/sphx_glr_plot_eof-smode_thumb.png
    :alt:

  :ref:`sphx_glr_content_user_guide_auto_examples_1single_plot_eof-smode.py`

.. raw:: html

      <div class="sphx-glr-thumbnail-title">Sparse PCA</div>
    </div>


.. raw:: html

    <div class="sphx-glr-thumbcontainer" tooltip="This tutorial illustrates the application of Extended EOF (EEOF) analysis to isolate and remove...">

.. only:: html

  .. image:: /content/user_guide/auto_examples/1single/images/thumb/sphx_glr_plot_eeof_trend_thumb.png
    :alt:

  :ref:`sphx_glr_content_user_guide_auto_examples_1single_plot_eeof_trend.py`

.. raw:: html

      <div class="sphx-glr-thumbnail-title">Removing nonlinear trends with EEOF analysis</div>
    </div>


.. raw:: html

    <div class="sphx-glr-thumbcontainer" tooltip="Multivariate EOF analysis.">

.. only:: html

  .. image:: /content/user_guide/auto_examples/1single/images/thumb/sphx_glr_plot_multivariate-eof_thumb.png
    :alt:

  :ref:`sphx_glr_content_user_guide_auto_examples_1single_plot_multivariate-eof.py`

.. raw:: html

      <div class="sphx-glr-thumbnail-title">Multivariate EOF analysis</div>
    </div>


.. raw:: html

    <div class="sphx-glr-thumbcontainer" tooltip="Multivariate EOF analysis with additional Varimax rotation.">

.. only:: html

  .. image:: /content/user_guide/auto_examples/1single/images/thumb/sphx_glr_plot_mreof_thumb.png
    :alt:

  :ref:`sphx_glr_content_user_guide_auto_examples_1single_plot_mreof.py`

.. raw:: html

      <div class="sphx-glr-thumbnail-title">Varimax-rotated Multivariate EOF analysis</div>
    </div>


.. raw:: html

    <div class="sphx-glr-thumbcontainer" tooltip="EOF (Empirical Orthogonal Function) analysis is commonly used in climate science, interpreting ...">

.. only:: html

  .. image:: /content/user_guide/auto_examples/1single/images/thumb/sphx_glr_plot_rotated_eof_thumb.png
    :alt:

  :ref:`sphx_glr_content_user_guide_auto_examples_1single_plot_rotated_eof.py`

.. raw:: html

      <div class="sphx-glr-thumbnail-title">Rotated EOF analysis</div>
    </div>


.. raw:: html

    <div class="sphx-glr-thumbcontainer" tooltip="Weighted EOF analysis (in S-mode) maximises the temporal variance considering each gridpoint wi...">

.. only:: html

  .. image:: /content/user_guide/auto_examples/1single/images/thumb/sphx_glr_plot_weighted-eof_thumb.png
    :alt:

  :ref:`sphx_glr_content_user_guide_auto_examples_1single_plot_weighted-eof.py`

.. raw:: html

      <div class="sphx-glr-thumbnail-title">Weighted EOF analysis</div>
    </div>


.. raw:: html

    <div class="sphx-glr-thumbcontainer" tooltip="TIn this demonstration, we&#x27;ll apply GWPCA to a dataset detailing the chemical compositions of s...">

.. only:: html

  .. image:: /content/user_guide/auto_examples/1single/images/thumb/sphx_glr_plot_gwpca_thumb.png
    :alt:

  :ref:`sphx_glr_content_user_guide_auto_examples_1single_plot_gwpca.py`

.. raw:: html

      <div class="sphx-glr-thumbnail-title">Geographically weighted PCA</div>
    </div>


.. raw:: html

    </div>

2 | Cross-Set Analysis
========================



.. raw:: html

    <div class="sphx-glr-thumbnails">


.. raw:: html

    <div class="sphx-glr-thumbcontainer" tooltip="Maximum Covariance Analysis (MCA) between two data sets.">

.. only:: html

  .. image:: /content/user_guide/auto_examples/2cross/images/thumb/sphx_glr_plot_mca_thumb.png
    :alt:

  :ref:`sphx_glr_content_user_guide_auto_examples_2cross_plot_mca.py`

.. raw:: html

      <div class="sphx-glr-thumbnail-title">Maximum Covariance Analysis</div>
    </div>


.. raw:: html

    <div class="sphx-glr-thumbcontainer" tooltip="Rotated Maximum Covariance Analysis (MCA) between two data sets.">

.. only:: html

  .. image:: /content/user_guide/auto_examples/2cross/images/thumb/sphx_glr_plot_rotated_mca_thumb.png
    :alt:

  :ref:`sphx_glr_content_user_guide_auto_examples_2cross_plot_rotated_mca.py`

.. raw:: html

      <div class="sphx-glr-thumbnail-title">Rotated Maximum Covariance Analysis</div>
    </div>


.. raw:: html

    </div>

3 | Multi-Set Analysis
========================



.. raw:: html

    <div class="sphx-glr-thumbnails">


.. raw:: html

    <div class="sphx-glr-thumbcontainer" tooltip="In this example, we&#x27;re going to perform a Canonical Correlation Analysis (CCA) on three dataset...">

.. only:: html

  .. image:: /content/user_guide/auto_examples/3multi/images/thumb/sphx_glr_plot_cca_thumb.png
    :alt:

  :ref:`sphx_glr_content_user_guide_auto_examples_3multi_plot_cca.py`

.. raw:: html

      <div class="sphx-glr-thumbnail-title">Canonical Correlation Analysis</div>
    </div>


.. raw:: html

    </div>

4 | Validation
===============


.. raw:: html

    <div class="sphx-glr-thumbnails">


.. raw:: html

    <div class="sphx-glr-thumbcontainer" tooltip="Test the significance of individual modes and obtain confidence intervals for both EOFs and PCs...">

.. only:: html

  .. image:: /content/user_guide/auto_examples/4validation/images/thumb/sphx_glr_plot_bootstrap_thumb.png
    :alt:

  :ref:`sphx_glr_content_user_guide_auto_examples_4validation_plot_bootstrap.py`

.. raw:: html

      <div class="sphx-glr-thumbnail-title">Significance testing of EOF analysis via bootstrap</div>
    </div>


.. raw:: html

    </div>


.. toctree::
   :hidden:
   :includehidden:


   /content/user_guide/auto_examples/1single/index.rst
   /content/user_guide/auto_examples/2cross/index.rst
   /content/user_guide/auto_examples/3multi/index.rst
   /content/user_guide/auto_examples/4validation/index.rst


.. only:: html

  .. container:: sphx-glr-footer sphx-glr-footer-gallery

    .. container:: sphx-glr-download sphx-glr-download-python

      :download:`Download all examples in Python source code: auto_examples_python.zip </content/user_guide/auto_examples/auto_examples_python.zip>`

    .. container:: sphx-glr-download sphx-glr-download-jupyter

      :download:`Download all examples in Jupyter notebooks: auto_examples_jupyter.zip </content/user_guide/auto_examples/auto_examples_jupyter.zip>`


.. only:: html

 .. rst-class:: sphx-glr-signature

    `Gallery generated by Sphinx-Gallery <https://sphinx-gallery.github.io>`_
